<?php
/**
 * Plugin Name:         RS Header & Footer
 * Description:         Really Simple plugin to insert headers, footers and Google Analytics tags.
 * Plugin URI:          https://plugins.seindal.dk/plugins/rs-header-footer/
 * Update URI:          https://plugins.seindal.dk
 * Author:              René Seindal
 * Author URI:          https://plugins.seindal.dk/
 * Donate link:         https://mypos.com/@historywalks
 * Requires Plugins:    rs-base-plugin
 * License:             GPL v2 or later
 * License URI:         https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:         rs-header-footer
 * Domain Path:         /languages
 * Requires PHP:        7.4
 * Requires at least:   5.0
 * Version:             1.4.1
 **/


namespace ReneSeindal;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

add_action( 'plugins_loaded', function() {
    class HeaderFooterPlugin extends PluginBase {
        protected $plugin_file = __FILE__;

        use PluginBaseSettings;

        /************************************************************************
         *
         * Header and footer output
         * - user level_0 is considered not logged in
         *
         ************************************************************************/

        function do_wp_head_action() {
            $head = '';

            if ( is_user_logged_in() && current_user_can( 'level_1' ) )
                $head = $this->get_option( 'user_header' );
            else {
                $head = $this->get_option( 'public_header' );
                $this->maybe_output_google_gtag( 'head' );
            }

            if ( ! empty( $head ) )
                echo $head, PHP_EOL;
        }

        function do_wp_footer_action() {
            $footer = '';

            if ( is_user_logged_in() && current_user_can( 'level_1' ) )
                $footer = $this->get_option( 'user_footer' );
            else {
                $footer = $this->get_option( 'public_footer' );
                $this->maybe_output_google_gtag( 'foot' );
            }

            if ( ! empty( $footer ) )
                echo $footer, PHP_EOL;
        }

        function maybe_output_google_gtag( $where ) {
            $id = $this->get_option( 'google_id' );
            if ( empty( $id ) )
                return;

            $placement = $this->get_option( 'google_placement' );
            if ( empty( $placement ) )
                return;

            if ( $placement !== $where )
                return;

            include plugin_dir_path( __FILE__ ) . 'assets/gtag.inc';
        }

        /************************************************************************
         *
         *	Settings
         *
         ************************************************************************/

        function do_admin_menu_action() {
            $this->settings_add_menu(
                __( 'RS Header Footer', 'rs-header-footer' ),
                __( 'RS Header Footer', 'rs-header-footer' )
            );
        }

        function settings_define_sections_and_fields() {
            // Google Analytics section

            $section = $this->settings_add_section(
                'analytics_section',
                __( 'Google analytics', 'rs-header-footer' ),
                __( 'These fields are for Google Analytics gtag.js.' )
            );

            $this->settings_add_field(
                'google_placement', $section,
                __( 'Placement', 'rs-header-footer' ),
                'settings_field_select_html',
                [
                    'default' => 'none',
                    'values' => [
                        'none' => __( 'Don\' use Google Analytics', 'rs-header-footer' ),
                        'head' => __( 'In the HTML header', 'rs-header-footer' ),
                        'foot' => __( 'In the HTML footer', 'rs-header-footer' ),
                    ],
                ]
            );

            $this->settings_add_field(
                'google_id', $section,
                __( 'Measurement ID', 'rs-header-footer' ),
                'settings_field_input_html'
            );


            // register section for public pages, not logged in

            $section = $this->settings_add_section(
                'public_section',
                __( 'Header & Footer for public pages', 'rs-header-footer' ),
                __( 'These fields are used on public pages, with no user logged in, or subscriber users.' )
            );

            $this->settings_add_field(
                'public_header', $section,
                __( 'Header', 'rs-header-footer' ),
                'settings_field_textarea_html'
            );

            $this->settings_add_field(
                'public_footer', $section,
                __( 'Footer', 'rs-header-footer' ),
                'settings_field_textarea_html'
            );

            // register section for public pages, user logged in

            $section = $this->settings_add_section(
                'user_section',
                __( 'Header & Footer for public pages, logged in users', 'rs-header-footer' ),
                __( 'These fields are used on public pages, for logged in users above subscriber.' )
            );

            $this->settings_add_field(
                'user_header', $section,
                __( 'Header', 'rs-header-footer' ),
                'settings_field_textarea_html'
            );

            $this->settings_add_field(
                'user_footer', $section,
                __( 'Footer', 'rs-header-footer' ),
                'settings_field_textarea_html'
            );
        }
    }

    new HeaderFooterPlugin();
} );
